# Dataset design

In this part of the documentation, you will find the dataset specification, starting with a brief overview of {doc}`Xarray <xarray:index>` on which the Quantify dataset is based, and examples of datasets that comply with that specification. Along with that, you will also find some information on the design choices and known limitations.

```{toctree}
:caption: Dataset design
:maxdepth: 1

Xarray introduction
Quantify dataset - specification
Quantify dataset - examples
Quantify dataset - advanced examples
```
